<!-- markdownlint-disable MD041 -->
:::{toctree}
:maxdepth: 2
:caption: Tutorial
:glob:
:hidden:

tutorial/*
:::

:::{toctree}
:maxdepth: 2
:caption: Contents
:glob:
:hidden:

contents/*
:::

:::{toctree}
:maxdepth: 4
:caption: Package
:glob:
:hidden:

package/*
autoapi/index
:::

:::{include} ../README.md
:::

## Indices and tables

* [](genindex)
* [](modindex)
